jQuery(document).ready(function() {
    console.log("Document ready");

    // Initialize tipvozila value
    var $tip_vozila = $("#tipvozila").val();
    console.log("Initial tipvozila value: " + $tip_vozila);

    // Adjust display based on the selected value initially
    adjustDisplay($tip_vozila);

    // Update tipvozila value on change and adjust display
    $("#tipvozila").change(function() {
        $tip_vozila = $(this).val();
        console.log("Updated tipvozila value: " + $tip_vozila);
        adjustDisplay($tip_vozila);
    });

    // Handle form submission
    $("#calculate").click(function(event) {
        event.preventDefault();  // Prevent default form submission
        console.log("Calculate button clicked");

        // Reset previous error messages
        $("label").css("color", "inherit");

        // Validacija inputov
        var $leto_val = $("#leto").val();
        var $mesec_val = $("#mesec").val();
        var $validation_mesec = 0;
        var $validation_leto = 0;
        var $validation_tip_vozila = 1; // Default to valid for non-electric cars

        console.log("mesec value: " + $mesec_val + "." + $leto_val);

        if ($mesec_val == null) {
            $("label[for='mesec']").css("color", "red");
            $("label[for='leto']").css("color", "red");  // Ensure the year label also turns red
        } else {
            $validation_mesec = 1;
        }

        if ($leto_val == null) {
            $("label[for='leto']").css("color", "red");
            $("label[for='mesec']").css("color", "red");  // Ensure the month label also turns red
        } else {
            $validation_leto = 1;
        }

        if ($tip_vozila === "avto" && $("#tipmotorja").val() !== "elektrika") {
            if ($("#co2").val() === "") {
                $("label[for='co2']").css("color", "red");
                $validation_tip_vozila = 0;
            } else {
                $validation_tip_vozila = 1;
            }
        }

        if ($validation_mesec && $validation_leto && $validation_tip_vozila) {
            console.log("Validation passed");
            izracun($tip_vozila);  // Pass $tip_vozila to izracun function
        } else {
            console.log("Validation failed");
        }
    });

    // Reset label color on input change
    $('#izracun select, #izracun input').change(function() {
        if ($(this).val() !== '' && $(this).val() !== null) {
            $(this).prev('label').css('color', 'inherit');
        }
    });

    // Function to adjust display based on tipvozila
    function adjustDisplay(tip_vozila) {
        if (tip_vozila === "avto") {
            $("#kw_row").hide();
            $("#co2_row").show();
        } else {
            $("#kw_row").show();
            $("#co2_row").hide();
        }
    }
});

function izracun($tip_vozila) {
    var $mesec = parseInt($("#mesec").val());
    var $leto = parseInt($("#leto").val());
    console.log("Izbrani datum: " + $mesec + "." + $leto);

    var $starost;
    if ($mesec === 0 || $leto === 0) {
        $starost = -99;
        console.log("Starost: novo vozilo");
    } else {
        var f = new Date($leto, $mesec - 1, 1); // Adjust for zero-based month
        var d = new Date();
        var $day_now = d.getDay();
        var $mesec_now = d.getMonth();
        var $leto_now = d.getFullYear();
        console.log("Trenutni datum: " + $day_now + "." + ($mesec_now + 1) + "." + $leto_now);

        var $meseci_avto = ($leto * 12 + $mesec);
        var $meseci_trenutno = ($leto_now * 12 + $mesec_now + 1);
        $starost = $meseci_trenutno - $meseci_avto;
        console.log("Starost: " + $starost + " mesecev");
    }

    var $co2 = $("#co2").val();
    var $kw = $("#kw").val();
    var $eur = $("#euronorma").val();
    var $motor = $("#tipmotorja").val();
    var $star_izracun = 0;

    // Simplify calculations for debugging
    var $eur_sum = 0;
    var $kw_sum = 0;
    var $co2_sum = 0;
    var $starost_sum = 1;

    console.log("Starting calculations");
    if ($motor !== "elektrika") {
        // Add calculations for non-electric vehicles
        // For now, just setting some example values
        $eur_sum = 100;
        $co2_sum = $co2 ? parseFloat($co2) * 1.2 : 0;
        $starost_sum = $starost > 0 ? 0.9 : 1; // Example calculation
    }

    var $dmv = ($eur_sum + $co2_sum + $kw_sum) * $starost_sum;
    console.log("DMV calculation completed: " + $dmv);

    var $html = "<p>DMV glede na EURO normo: " + ($eur_sum).toFixed(2) + "€<br/>";
    $html += "DMV glede na izpuste CO2: " + ($co2_sum).toFixed(2) + "€<br/>";
    $html += "DMV glede moč motorja: " + ($kw_sum).toFixed(2) + "€<br/>";
    $html += "Znižanje DMV glede na starost za: " + ((1 - $starost_sum) * 100).toFixed(0) + " %<br />";
    $html += "<strong>Skupni znesek novega DMV: " + ($dmv).toFixed(2) + "€</strong></p>";

    $("#izracunmodal").html($html);
    $("#email-podrobenizracun").html($html);
    $("#results").slideDown();
    $("#forma-povprasevanje-dmv").slideDown();

    $("input[data-dmv='euro-norma']").val(($eur_sum).toFixed(2) + "€");
    $("input[data-dmv='izpust-co']").val(($co2_sum).toFixed(2) + "€");
    $("input[data-dmv='moc-motorja']").val(($kw_sum).toFixed(2) + "€");
    $("input[data-dmv='znizanje-starost']").val(((1 - $starost_sum) * 100).toFixed(0) + " %");
    $("input[data-dmv='skupni-znesek']").val(($dmv).toFixed(2) + "€");
    $("input[data-dmv='davek-dmv']").val(($dmv).toFixed(2) + "€");
}
