document.addEventListener('DOMContentLoaded', function() {
    var header = document.querySelector('.main-header');
    var logoContainer = document.querySelector('.main-logo-container');
    var logo = document.querySelector('.main-logo');
    var navLeft = document.querySelector('.nav-left');
    var navRight = document.querySelector('.nav-right');
    var mobileTopBar = document.querySelector('.mobile-top-bar');
    var menuButton = document.querySelector('.menu-button');
    var navbar = document.querySelector('.main-navibar');
    var mobileMenu = document.getElementById('mobileMenu');
    var body = document.querySelector('body');
    var isMobile = window.innerWidth <= 768;

    menuButton.addEventListener('click', function() {
        mobileMenu.classList.toggle('active');
        body.classList.toggle('no-scroll');
        mobileTopBar.style.display = mobileMenu.classList.contains('active') ? 'none' : 'flex';
    });

    // Dodajanje event listenerjev za povezave v meniju
    var menuLinks = document.querySelectorAll('.mobile-menu-links a');
    menuLinks.forEach(function(link) {
        link.addEventListener('click', function() {
            mobileMenu.classList.remove('active');
            body.classList.remove('no-scroll');
            mobileTopBar.style.display = 'flex';
        });
    });

    function startMobileAnimation() {
        const carouselItems = document.querySelectorAll('.carousel-item');
        carouselItems.forEach((item) => {
            item.style.transform = 'translateX(-100%)';  // Premakni vsak element v levo
            item.style.transition = 'transform 2s ease-in-out';  // Dodaj prehod
        });
    }

    function startAnimation() {
        const carousel = document.querySelector('.carousel');
        const companyLogo = document.querySelector('.company-logo');
        const carouselItems = document.querySelectorAll('.carousel-item');

        if (isInViewport(carousel)) {  // Preverite, če je carousel v vidnem polju
            carouselItems.forEach((item, index) => {
                if (index < 3) {
                    item.classList.add('carousel-item-left');
                } else {
                    item.classList.add('carousel-item-right');
                }
            });
            if (!isMobile) {  // Če ni mobilna naprava, animiraj tudi logo
                companyLogo.classList.add('carousel-visible');
            }
        }
    }

    function isInViewport(element) {
        const rect = element.getBoundingClientRect();
        return (
            rect.top >= 0 &&
            rect.left >= 0 &&
            rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.right <= (window.innerWidth || document.documentElement.clientWidth)
        );
    }

    function adjustHeaderOnScroll() {
        var scrollY = window.scrollY;
        var scrollMax = 300;
        var scrollRatio = Math.min(scrollY / scrollMax, 1);

        if (scrollY < scrollMax) {
            logoContainer.style.transform = `translate(-50%, -${scrollY / 2}px) scale(${1 - scrollRatio * 0.5})`;
            logoContainer.style.opacity = 1 - scrollRatio;
        } else {
            logoContainer.style.transform = 'translate(-50%, -50%) scale(0.5)';
            logoContainer.style.opacity = 1;
        }

        if (scrollRatio === 1) {
            header.classList.add('shrink');
            logo.src = 'assets/img/Sampel-LOGO-avtovizija.png';
        } else {
            header.classList.remove('shrink');
            logo.src = 'assets/img/Sampel-LOGO.png';
        }

        navLeft.style.transform = `translateX(${-100 * scrollRatio}%)`;
        navRight.style.transform = `translateX(${100 * scrollRatio}%)`;
    }

    // Swiper initialisation
    var mySwiper = new Swiper('.mySwiper', {
        effect: "coverflow",
        slidesPerView: 1,
        spaceBetween: 30,
        grabCursor: true,
        centeredSlides: true,
        slidesPerView: "auto",
        initialSlide: 1, // Center second slide
        navigation: {
            nextEl: '.swiper-button-next',
            prevEl: '.swiper-button-prev',
        },
        coverflowEffect: {
            rotate: 50,
            stretch: 0,
            depth: 100,
            modifier: 1,
            slideShadows: true,
        },
        pagination: {
            el: ".swiper-pagination",
            clickable: true,
        },
        breakpoints: {
            0: {
                slidesPerView: 1,
                spaceBetween: 20,
            },
            640: {
                slidesPerView: 1,
                spaceBetween: 20,
            },
            900: {
                slidesPerView: 2,
                spaceBetween: 30,
            },
            1024: {
                slidesPerView: 2,
                spaceBetween: 40,
            },
            1200: {
                slidesPerView: 3,
                spaceBetween: 40,
            },
        }
    });

    window.addEventListener('resize', function() {
        isMobile = window.innerWidth <= 768;  // Preverjanje ob spremembi velikosti okna
        if (isMobile) {
            startMobileAnimation();  // Zaženi mobilno animacijo, če je velikost ustrezna
        } else {
            startAnimation();  // Sicer zaženi standardno animacijo
        }
    });

    window.addEventListener('scroll', function() {
        var sticky = header.offsetTop;

        if (window.pageYOffset > sticky) {
            header.classList.add("sticky");
        } else {
            header.classList.remove("sticky");
        }

        adjustHeaderOnScroll();
        startAnimation();  // Zaženite animacijo samo, ko je sekcija v vidnem polju
    });

    adjustHeaderOnScroll();

    if (isMobile) {
        startMobileAnimation();
    } else {
        startAnimation();
    }
});
