<?php

class HelperOglasi {
    private $oglasi;
    private $startTime;

    public function __construct($filePath) {
        $this->startTime = microtime(true);

        // Merjenje časa pred branjem datoteke
        $t1 = microtime(true);
        $jsonData = file_get_contents($filePath);
        $t2 = microtime(true);
        error_log("Čas branja datoteke JSON: " . ($t2 - $t1) . "s");

        // Merjenje časa za json_decode
        $t1 = microtime(true);
        $this->oglasi = json_decode($jsonData, true);
        $t2 = microtime(true);
        error_log("Čas za json_decode: " . ($t2 - $t1) . "s");

        // Skupni čas konstruktorja
        $end = microtime(true);
        error_log("Čas konstruktorja HelperOglasi: " . ($end - $this->startTime) . "s");
    }

    public function getOsnovniPodatki($id) {
        return $this->oglasi[$id]['osnovniPodatki'] ?? null;
    }

    public function getOstaliPodatki($id) {
        return $this->oglasi[$id]['ostaliPodatki'] ?? null;
    }

    public function getPorabaInEmisije($id) {
        return $this->oglasi[$id]['porabaInEmisije'] ?? null;
    }

    function getZnamke($vehicles) {
        $t1 = microtime(true);
        $brands = array();

        foreach ($vehicles as $vehicle) {
            $brand = $vehicle['osnovniPodatki']['znamka'];
            if (!in_array($brand, $brands)) {
                $brands[] = $brand;
            }
        }

        $t2 = microtime(true);
        error_log("Čas za getZnamke: " . ($t2 - $t1) . "s");
        return $brands;
    }

    public function getVozilo($id) {
        return $this->oglasi[$id] ?? null;
    }

    public function getOpremaInOstalo($id) {
        return $this->oglasi[$id]['opremaInOstalo'] ?? null;
    }




    public function getVozilaByOffsetLimit($offset, $limit, $znamka = null, $minCena = 0, $maxCena = 1000000) {
        $filteredVozila = array_filter($this->oglasi, function($v) use ($znamka, $minCena, $maxCena) {
            $znamkaOk = $znamka ? strtolower($v['osnovniPodatki']['znamka']) === strtolower($znamka) : true;

            $cenaVozila = isset($v['osnovniPodatki']['cena']) ? (int) preg_replace('/[^\d]/', '', $v['osnovniPodatki']['cena']) : 0;

            return (!$znamka || $znamka == strtolower($v['osnovniPodatki']['znamka']))
                && $cenaVozila >= $minCena
                && $cenaVozila <= $maxCena;
        });

        return array_slice($filteredVozila, $offset, $limit, true);
    }

    public function getVsaVozila($limit = null, $getAll = false) {
        $t1 = microtime(true);
        $oglasi = $this->oglasi;

        if ($getAll) {
            $t2 = microtime(true);
            error_log("Čas za getVsaVozila (getAll=true): " . ($t2 - $t1) . "s");
            return $oglasi;
        }

        if ($limit !== null && is_int($limit) && $limit > 0) {
            $rez = array_slice($oglasi, 0, $limit, true);
            $t2 = microtime(true);
            error_log("Čas za getVsaVozila z limit=" . $limit . ": " . ($t2 - $t1) . "s");
            return $rez;
        }

        $t2 = microtime(true);
        error_log("Čas za getVsaVozila brez omejitev: " . ($t2 - $t1) . "s");
        return $oglasi;
    }

    // API klici lahko povzročijo zamude, zato lahko tudi tu dodamo meritve časa
    function getVoziloSlikeViaAPI($oglasID) {
        $apiKey = '69a007373f7f1c914554c5e60541e413';
        $apiUrl = "https://avtovizija.net/api/vozilo/getPhotos?idOglasa=" . urlencode($oglasID);

        $t1 = microtime(true);
        $context = stream_context_create([
            'http' => [
                'method' => 'GET',
                'header' => "x-api-key: $apiKey\r\n"
            ]
        ]);

        try {
            $response = @file_get_contents($apiUrl, false, $context);
            if ($response === FALSE) {
                throw new Exception("Napaka pri doseganju API-ja");
            }
            $data = json_decode($response, true);
            $slike = [];
            if (!empty($data['slike'])) {
                foreach ($data['slike'] as $slika) {
                    if (isset($slika['imageData'])) {
                        $slike[] = $slika['imageData'];
                    }
                }
            }
            $t2 = microtime(true);
            error_log("Čas za getVoziloSlikeViaAPI($oglasID): " . ($t2 - $t1) . "s");
            return $slike;
        } catch (Exception $e) {
            error_log("Prišlo je do napake: " . $e->getMessage());
            return [];
        }
    }

    function getPridobiSlikePodpisaneURL($oglasID) {
        $apiKey = '69a007373f7f1c914554c5e60541e413';
        $apiUrl = "https://avtovizija.net/api/vozilo/getPhotosUrl?idOglasa=" . urlencode($oglasID);

        $t1 = microtime(true);
        $context = stream_context_create([
            'http' => [
                'method' => 'GET',
                'header' => "x-api-key: $apiKey\r\n"
            ]
        ]);

        try {
            $response = @file_get_contents($apiUrl, false, $context);
            if ($response === FALSE) {
                throw new Exception("Napaka pri doseganju API-ja");
            }
            $data = json_decode($response, true);
            $t2 = microtime(true);
            error_log("Čas za getPridobiSlikePodpisaneURL($oglasID): " . ($t2 - $t1) . "s");
            return $data['slike'] ?? [];
        } catch (Exception $e) {
            error_log("Prišlo je do napake: " . $e->getMessage());
            return [];
        }
    }

    function getNaslovnaSlika($oglasID) {
        $apiKey = '69a007373f7f1c914554c5e60541e413';
        $apiUrl = "https://avtovizija.net/api/vozilo/getPhotoByIndex?idOglasa=" . urlencode($oglasID) . "&index=0";

        $t1 = microtime(true);
        $context = stream_context_create([
            'http' => [
                'method' => 'GET',
                'header' => "x-api-key: $apiKey\r\n"
            ]
        ]);

        try {
            $response = @file_get_contents($apiUrl, false, $context);
            if ($response === FALSE) {
                throw new Exception("Napaka pri doseganju API-ja");
            }
            $data = json_decode($response, true);
            $t2 = microtime(true);
            error_log("Čas za getNaslovnaSlika($oglasID): " . ($t2 - $t1) . "s");
            return $data['slika'] ?? null;
        } catch (Exception $e) {
            error_log("Prišlo je do napake: " . $e->getMessage());
            return null;
        }
    }
}
