document.addEventListener('DOMContentLoaded', () => {

    const AJAX_URL = 'helperji/ajax_load_cars.php';
    const LIMIT_DB = 24;
    const SHOW_STEP = 12;

    let offset = 0;
    let carsBuffer = [];
    let indexInChunk = 0;

    const carsGrid = document.getElementById('carsGrid');
    const loadMoreBtn = document.getElementById('loadMoreBtn');

    window.loadNextChunk = function(resetOffset = false) {
        if (resetOffset) {
            offset = 0;
            carsGrid.innerHTML = '';
        }

        const selectedBrands = Array.from(document.querySelectorAll('.categories-box input[type="checkbox"]:checked'))
            .map(cb => cb.value.toLowerCase());

        const minCena = parseInt(document.getElementById('min-value').value) || 0;
        const maxCena = parseInt(document.getElementById('max-value').value) || 1000000;

        const urlParams = new URLSearchParams({
            offset: offset,
            limit: LIMIT_DB,
            minCena: minCena,
            maxCena: maxCena
        });

        if (selectedBrands.length === 1) {
            urlParams.append('znamka', selectedBrands[0]);
        }

        const url = `${AJAX_URL}?${urlParams}`;

        fetch(url)
            .then(resp => resp.json())
            .then(data => {
                if (data.status === 'OK' && data.count > 0) {
                    carsBuffer = data.results;
                    indexInChunk = 0;
                    offset += data.count;
                    showMoreFromBuffer();
                } else {
                    loadMoreBtn.style.display = 'none';
                }
            })
            .catch(err => {
                console.error('Napaka pri AJAX:', err);
                loadMoreBtn.style.display = 'none';
            });
    }

    function showMoreFromBuffer() {
        const remaining = carsBuffer.length - indexInChunk;
        const takeCount = Math.min(SHOW_STEP, remaining);
        const subset = carsBuffer.slice(indexInChunk, indexInChunk + takeCount);

        subset.forEach(renderCar);

        indexInChunk += takeCount;

        // Skrij gumb, če ni več oglasov
        if (indexInChunk >= carsBuffer.length && carsBuffer.length < LIMIT_DB) {
            loadMoreBtn.style.display = 'none';
        } else {
            loadMoreBtn.style.display = 'inline-block';
        }
    }

    function renderCar(vozilo) {
        const { id, osnovniPodatki, ostaliPodatki } = vozilo;
        const znamka = osnovniPodatki.znamka || '';
        const model = osnovniPodatki.model || '';
        const cena = osnovniPodatki.cena ? `${osnovniPodatki.cena} €` : 'Pokličite za ceno';
        const letnik = ostaliPodatki['Leto proizvodnje'] || 'Ni podatka';
        const gorivo = ostaliPodatki['Vrsta goriva']?.replace(/ motor| pogon/g, '') || 'Ni podatka';
        const menjalnik = ostaliPodatki['Menjalnik']?.replace(' menjalnik', '') || 'Ni podatka';

        fetch(`helperji/getSlika.php?id=${encodeURIComponent(id)}`)
            .then(resp => resp.json())
            .then(data => {
                const imgSrc = data.slika || 'images/resource/vzorcna-slika.webp';
                const el = document.createElement('div');
                el.className = 'service-block-thirteen';
                el.setAttribute('data-brand', znamka.toLowerCase());

                el.innerHTML = `
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image">
                                <a href="podrobnosti.php?vozilo=${encodeURIComponent(id)}">
                                    <img src="${imgSrc}" alt="${escapeHtml(znamka)} ${escapeHtml(model)}" />
                                </a>
                            </figure>
                        </div>
                        <div class="right-box">
                            <div class="content-box">
                                <h4 class="title"><a href="podrobnosti.php?vozilo=${encodeURIComponent(id)}">${escapeHtml(znamka)}, ${escapeHtml(model)}</a></h4>
                                <div class="text">${escapeHtml(letnik)} | ${escapeHtml(gorivo)} | ${escapeHtml(menjalnik)}</div>
                                <div class="inspection-sec">
                                    <div class="inspection-box">
                                        <span class="icon"></span>
                                        <div class="info">
                                            <span>Kilometri</span>
                                            <small>${escapeHtml(letnik)}</small>
                                        </div>
                                    </div>
                                    <div class="inspection-box">
                                        <span class="icon"></span>
                                        <div class="info">
                                            <span>Gorivo</span>
                                            <small>${escapeHtml(gorivo)}</small>
                                        </div>
                                    </div>
                                    <div class="inspection-box">
                                        <span class="icon"></span>
                                        <div class="info">
                                            <span>Menjalnik</span>
                                            <small>${escapeHtml(menjalnik)}</small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="content-box-two">
                                <h4 class="title">${escapeHtml(cena)}</h4>
                                <a href="podrobnosti.php?vozilo=${encodeURIComponent(id)}" class="button">Podrobnosti</a>
                            </div>
                        </div>
                    </div>`;

                carsGrid.appendChild(el);
            })
            .catch(err => console.error('Napaka pri sliki:', err));
    }

    function escapeHtml(str) {
        if (typeof str !== 'string') return str;
        return str
            .replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;')
            .replace(/"/g, '&quot;');
    }

    loadMoreBtn.addEventListener('click', () => {
        const remaining = carsBuffer.length - indexInChunk;
        if (remaining > 0) {
            showMoreFromBuffer();
        } else {
            loadNextChunk();
        }
    });

    document.querySelectorAll('.categories-box input[type="checkbox"]').forEach(cb => {
        cb.addEventListener('change', () => {
            document.querySelectorAll('.categories-box input[type="checkbox"]').forEach(otherCb => {
                if (otherCb !== cb) otherCb.checked = false;
            });
            loadMoreBtn.style.display = 'inline-block';
            loadNextChunk(true);
        });
    });

    const slider = document.getElementById('slider-val');
    if (slider && slider.noUiSlider) {
        slider.noUiSlider.on('set', () => {
            loadMoreBtn.style.display = 'inline-block';
            loadNextChunk(true);
        });
    }

    // Prvo nalaganje brez izbrane znamke:
    loadNextChunk(true);
});
