(function ($) {
  "use strict";

  // Hide Loading Box (Preloader)
  function preloader() {
    if ($(".preloader").length) {
      $(".preloader").delay(200).fadeOut(500);
    }
  }

  // Update Header Style and Scroll to Top
  function headerStyle() {
    var header = document.querySelector('.main-header');
    var sticky = header.offsetTop;

    if (window.pageYOffset > sticky) {
      header.classList.add("sticky");
    } else {
      header.classList.remove("sticky");
    }
  }

  // Animacija headerja pri skrolanju
  function adjustHeaderOnScroll() {
    var header = document.querySelector('.main-header');
    var logoContainer = document.querySelector('.main-logo-container');
    var logo = document.querySelector('.main-logo');
    var navLeft = document.querySelector('.nav-left');
    var navRight = document.querySelector('.nav-right');



    if (header && logoContainer && navLeft && navRight) {
      var scrollY = window.scrollY;
      var scrollMax = 300;
      var scrollRatio = Math.min(scrollY / scrollMax, 1);


      if (scrollY < scrollMax) {
        logoContainer.style.transform = `translate(-50%, -${scrollY / 2}px) scale(${1 - scrollRatio * 0.5})`;
        logoContainer.style.opacity = 1 - scrollRatio;
      } else {
        logoContainer.style.transform = 'translate(-50%, -50%) scale(0.5)';
        logoContainer.style.opacity = 1;
      }

      if (scrollRatio === 1) {
        header.classList.add('shrink');
        logo.src = 'images/logo.png';
      } else {
        header.classList.remove('shrink');
        logo.src = 'images/logo.png';
      }

      navLeft.style.transform = scrollY > scrollMax ? "translateX(-100%)" : "translateX(0)";
      navRight.style.transform = scrollY > scrollMax ? "translateX(100%)" : "translateX(0)";
    }
  }

  // Submenu Dropdown Toggle
  if ($(".boxcar-header li.dropdown ul").length) {
    $(".boxcar-header .navigation li.dropdown").append(
        '<div class="dropdown-btn"><i class="fa fa-angle-down"></i></div>'
    );
  }

  // Header Search
  if ($(".search-btn").length) {
    $(".search-btn").on("click", function () {
      $(".boxcar-header").addClass("moblie-search-active");
    });
    $(".close-search, .search-back-drop").on("click", function () {
      $(".boxcar-header").removeClass("moblie-search-active");
    });
  }

  // Fact Counter + Text Count
  if ($(".widget-counter").length) {
    $(".widget-counter").appear(
        function () {
          var $t = $(this),
              n = $t.find(".count-text").attr("data-stop"),
              r = parseInt($t.find(".count-text").attr("data-speed"), 10);

          if (!$t.hasClass("counted")) {
            $t.addClass("counted");
            $(
                {
                  countNum: $t.find(".count-text").text(),
                }
            ).animate(
                {
                  countNum: n,
                },
                {
                  duration: r,
                  easing: "linear",
                  step: function () {
                    $t.find(".count-text").text(Math.floor(this.countNum));
                  },
                  complete: function () {
                    $t.find(".count-text").text(this.countNum);
                  },
                }
            );
          }
        },
        { accY: 0 }
    );
  }

  // Scroll to target
  var goTop = function () {
    if ($(".scroll-to-target").length) {
      $(".scroll-to-target").on("click", function () {
        var target = $(this).attr("data-target");
        $("html, body").animate(
            {
              scrollTop: $(target).offset().top,
            },
            1500
        );
      });
    }
  };

  // Elements Animation
  if ($(".wow").length) {
    var wow = new WOW({
      boxClass: "wow",
      animateClass: "animated",
      offset: 0,
      mobile: false,
      live: true,
    });
    wow.init();
  }

  // Search box functionality
  var boxSearch = function () {
    $(document).on("click", function (e) {
      var clickID = e.target.id;
      if (clickID !== "s") {
        $(".box-content-search").removeClass("active");
        $(".layout-search").removeClass("active");
        $(".show-search").val("");
      }
    });

    $(".show-search").on("click", function (event) {
      event.stopPropagation();
    });

    var input = $(".layout-search").find("input");
    input.on("input", function () {
      if ($(this).val().trim() !== "") {
        $(".box-content-search").addClass("active");
        $(".layout-search").addClass("active");
      } else {
        $(".box-content-search").removeClass("active");
        $(".layout-search").removeClass("active");
      }
    });
  };

  // Initialize functions on scroll and load
  $(window).on("scroll", function () {
    headerStyle();
    adjustHeaderOnScroll();
  });

  $(window).on("load", function () {
    preloader();
    headerStyle();
    goTop();
    boxSearch();
  });
})(window.jQuery);
